=======
History
=======

1.1.0
-----

- Removed the minimum size limit for a detected issue report list
- Added an :code:`as_list` option to the detected issue response model to support non-object input


1.0.0
-----

- Added all models originally in PythX
- Extended models with :code:`BaseModel` class
- Make issue reports and various submodels JSON serializable
- Added documentation to readthedocs.io
- Added CI with Travis
- Added coverage metrics with codecov
- Added packaging pipeline to PyPI
